c HPLS from HPOLY
*     J. Ablinger, J. Bl\"umlein, M. Round and C. Schneider
*     Numerical Implementation of Harmonic Polylogarithms to Weight w = 8
*     DESY 13-064, DO-TH 17/12, arXive:1809.07084 [hep-ph].
c Modified by Leandro Cieri 03/08/2020

c!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
c!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
c             HPLS  Peso 4 Basis From Bl\"umlein
c!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
c!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
C All elements checked 10.08.2020 Leandro

      function HB0111(x) !B1
      implicit none
      include 'types.f'
      include 'constants.f'
      include 'HPLsinclude.f'
      real(dp):: x,HB0111,myli2,myli3,myli4,Zeta
      external Zeta
      external myli3
      external myli2,myli4
c
      HB0111 = Pi
      HB0111 = Pi**4/90._dp - (Pi**2*Log(1._dp - x)**2)/12._dp + (Log(1._dp - x)**3*Log(x))/3._dp + 
     -  (Log(1._dp - x)**2*myli2(x))/2._dp + Log(1._dp - x)*myli3(1._dp - x) - myli4(1._dp - x)
      
      return
      end 


      function HB0011(x) !B2
      implicit none
      include 'types.f'
      include 'constants.f'
      include 'HPLsinclude.f'
      real(dp):: x,HB0011,myli2,myli3,myli4,Zeta,li4half,y
      external Zeta
      external myli3
      external myli2,myli4
      real(dp):: HBm1m110
      real(dp):: HB0111,HB0001,HBm1111,HBm1110,HBm1101,HBm1100,
     & HBm1011,HBm1010,HBm1001,HBm1000,HBm10m11
      real(dp):: HBm1m1m10,HBm1m1m11,HBm1m100,HBm1m101,HBm1m111
c        
      external HBm1m110
      external HB0111,HB0001,HBm1111,HBm1110,HBm1101,HBm1100,
     & HBm1011,HBm1010,HBm1001,HBm1000,HBm10m11
      external HBm1m1m10,HBm1m1m11,HBm1m100,HBm1m101,HBm1m111
c
      REAL*8   HB1,HB2,HB3,HB4
      INTEGER  IW 
      COMMON/WEIGHT/ IW
*  
      EXTERNAL HB1,HB2,HB3,HB4
c
      HB0011 = zip
      li4half = 0.5174790616738993_dp
      if(0._dp<x.and.x<(sqrt(2._dp)-1._dp))then
      HB0011 = HB4(0,0,1,1,x)
      elseif((sqrt(2._dp)-1._dp)<x.and.x<1._dp)then
      y = (1._dp - x)/(1._dp + x)
      HB0011 = Pi**4/360._dp + H1h(y)*H3h(y) - HB4(0,0,1,1,y) - HBm1001(y) - HBm1010(y) - 
     -  HBm1101(y) - HBm1110(y) + HBm1m100(y) - HBm1m101(y) + HBm1m110(y) - 
     -  HBm1m111(y) + 2._dp*HBm1m1m10(y) + 2._dp*HBm1m1m11(y) - H21(y)*Hm1(y) + 
     -  H1h(y)*H2h(y)*Hm1(y) + (H1h(y)**2*Hm1(y)**2)/4._dp + (H1h(y)*Hm1(y)**3)/6._dp + 
     -  Hm1(y)**4/24._dp - H1h(y)*Hm1(y)*Hm10(y) + H1h(y)*Hm100(y) - 
     -  H1h(y)*Hm1(y)*Hm11(y) + H1h(y)*Hm110(y) + Hm1(y)*Hm111(y) + Hm1(y)*Hm12(y) + 
     -  H1h(y)*Hm1m10(y) - Hm1(y)*Hm1m10(y) + H1h(y)*Hm1m11(y) - Hm1(y)*Hm1m11(y) + 
     -  H21(y)*Ho(y) - H1h(y)*H2h(y)*Ho(y) - (H1h(y)**2*Hm1(y)*Ho(y))/2._dp + 
     -  (H1h(y)**2*Ho(y)**2)/4._dp + H21(y)*Log(2._dp) - H1h(y)*H2h(y)*Log(2._dp) - 
     -  (H1h(y)**2*Hm1(y)*Log(2._dp))/2._dp - (H1h(y)*Hm1(y)**2*Log(2._dp))/2._dp - 
     -  (Hm1(y)**3*Log(2._dp))/6._dp + H1h(y)*Hm10(y)*Log(2._dp) + H1h(y)*Hm11(y)*Log(2._dp) - 
     -  Hm111(y)*Log(2._dp) - Hm12(y)*Log(2._dp) + Hm1m10(y)*Log(2._dp) + Hm1m11(y)*Log(2._dp) + 
     -  (H1h(y)**2*Ho(y)*Log(2._dp))/2._dp + (H1h(y)**2*Log(2._dp)**2)/4._dp + 
     -  (H1h(y)*Hm1(y)*Log(2._dp)**2)/2._dp + (Hm1(y)**2._dp*Log(2._dp)**2)/4._dp - H1h(y)*Zeta(3) - 
     -  Hm1(y)*Zeta(3) 
      
      else
      write(*,*)' x out of range HBm1110.  x = ',x
      endif
      
      return
      end 

      function HB0001(x) !B3 Checked
      implicit none
      include 'types.f'
      include 'constants.f'
      include 'HPLsinclude.f'
      real(dp):: x,HB0001,myli2,myli3,myli4,Zeta,y
      external Zeta
      external myli3
      external myli2,myli4
      REAL*8   HB1,HB2,HB3,HB4
      INTEGER  IW 
      COMMON/WEIGHT/ IW
*  
      EXTERNAL HB1,HB2,HB3,HB4
c
      HB0001 = myli4(x)
      
      return
      end 


      function HBm1111(x) !B4
      implicit none
      include 'types.f'
      include 'constants.f'
      include 'HPLsinclude.f'
      real(dp):: x,HBm1111,myli2,myli3,myli4,Zeta,li4half,y
      external Zeta
      external myli3
      external myli2,myli4
      real(dp):: HBm1m110
      real(dp):: HB0111,HB0001,HBm1110,HBm1101,HBm1100,
     & HBm1011,HBm1010,HBm1001,HBm1000,HBm10m11
      real(dp):: HBm1m1m10,HBm1m1m11,HBm1m100,HBm1m101,HBm1m111
c        
      external HBm1m110
      external HB0111,HB0001,HBm1110,HBm1101,HBm1100,
     & HBm1011,HBm1010,HBm1001,HBm1000,HBm10m11
      external HBm1m1m10,HBm1m1m11,HBm1m100,HBm1m101,HBm1m111
c
      REAL*8   HB1,HB2,HB3,HB4
      INTEGER  IW 
      COMMON/WEIGHT/ IW
*  
      EXTERNAL HB1,HB2,HB3,HB4
c
      HBm1111 = zip
      li4half = 0.5174790616738993_dp
      if(0._dp<x.and.x<(sqrt(2._dp)-1._dp))then
      HBm1111 = HB4(-1,1,1,1,x)
      elseif((sqrt(2._dp)-1._dp)<x.and.x<1._dp)then
      y = (1._dp - x)/(1._dp + x)
      HBm1111 = li4half + HBm1000(y) + HBm1m100(y) + HBm1m1m10(y) - 
     -  Hm1(y)**4/24._dp + (Hm1(y)**2*Hm10(y))/2. - Hm1(y)*Hm100(y) - 
     -  Hm1(y)*Hm1m10(y) + (Hm1(y)**3*Log(2._dp))/6._dp - 
     -  Hm1(y)*Hm10(y)*Log(2._dp) + Hm100(y)*Log(2._dp) + 
     -  Hm1m10(y)*Log(2._dp) - (Hm1(y)**2*Log(2._dp)**2)/4._dp + 
     -  (Hm10(y)*Log(2._dp)**2)/2._dp + (Hm1(y)*Log(2._dp)**3)/6._dp
      
      else
      write(*,*)' x out of range HBm1111.  x = ',x
      endif
      
      return
      end 


      function HBm1110(x) !B5 Checked
      implicit none
      include 'types.f'
      include 'constants.f'
      include 'HPLsinclude.f'
      real(dp):: x,myli2,myli3,myli4,Zeta,y,li4half,HBm1110,HBm10m11
      external Zeta
      external myli3
      external myli2,myli4,HBm10m11
c
      REAL*8   HB1,HB2,HB3,HB4
      INTEGER  IW 
      COMMON/WEIGHT/ IW
*  
      EXTERNAL HB1,HB2,HB3,HB4
c
      HBm1110 = zip
      li4half = 0.5174790616738993_dp
      if(0._dp<x.and.x<(sqrt(2._dp)-1._dp))then
      HBm1110 = HB4(-1,1,1,0,x)
      elseif((sqrt(2._dp)-1._dp)<x.and.x<1._dp)then
      y = (1._dp - x)/(1._dp + x)
      HBm1110 =  -li4half - Pi**4/720._dp - HBm10m11(y) + (Pi**2*Hm1(y)**2)/12._dp + Hm1(y)**4/24._dp - 
     -  (Pi**2*Hm10(y))/6._dp - (Hm1(y)**2*Hm10(y))/2._dp - Hm10(y)**2/2._dp + Hm1(y)*Hm100(y) + 
     -  Hm13(y) + Hm1(y)*Hm1m10(y) - Hm1m12(y) + Hm1m1m11(y) - 
     -  (Pi**2*Hm1(y)*Log(2._dp))/6._dp - Log(2._dp)**4/24._dp - Hm1(y)*Zeta(3) + (Log(2._dp)*Zeta(3))/8._dp
      else
      write(*,*)' x out of range HBm1110.  x = ',x
      endif
      
      return
      end 
      
      function HBm1101(x) !B6 Checked
      implicit none
      include 'types.f'
      include 'constants.f'
      include 'HPLsinclude.f'
      real(dp):: HBm1101,x,myli2,myli3,myli4,Zeta,y,li4half,HBm10m11,HBm1m110
      external Zeta
      external myli3
      external myli2,myli4,HBm10m11,HBm1m110
      REAL*8   HB1,HB2,HB3,HB4
      INTEGER  IW 
      COMMON/WEIGHT/ IW
*  
      EXTERNAL HB1,HB2,HB3,HB4
c
      HBm1101 = zip
      li4half = 0.5174790616738993_dp
      if(0._dp<x.and.x<(sqrt(2._dp)-1._dp))then
      HBm1101 = HB4(-1,1,0,1,x)
      elseif((sqrt(2._dp)-1._dp)<x.and.x<1._dp)then
      y = (1._dp - x)/(1._dp + x)
      HBm1101 =     -li4half + (19._dp*Pi**4)/1440._dp + HBm10m11(y) - HBm1m110(y) - 
     -  (Pi**2*Hm1(y)**2)/12._dp + Hm1(y)**4/24._dp + (Pi**2*Hm10(y))/6. - 
     -  (Hm1(y)**2*Hm10(y))/2._dp + Hm10(y)**2/2._dp - Hm1(y)*Hm12(y) + Hm120(y) + 
     -  2._dp*Hm1(y)*Hm1m10(y) - 2._dp*Hm1m100(y) + Hm1(y)*Hm1m11(y) + 2._dp*Hm1m12(y) - 
     -  4._dp*Hm1m1m10(y) - 3._dp*Hm1m1m11(y) + (Pi**2*Hm1(y)*Log(2._dp))/6._dp - 
     -  (Hm1(y)**3*Log(2._dp))/6._dp + Hm1(y)*Hm10(y)*Log(2._dp) + Hm12(y)*Log(2._dp) - 
     -  2._dp*Hm1m10(y)*Log(2._dp) - Hm1m11(y)*Log(2._dp) - (Pi**2*Log(2._dp)**2)/24. - Log(2._dp)**4/24._dp + 
     -  2._dp*Hm1(y)*Zeta(3) - (Log(2._dp)*Zeta(3))/4._dp
      else
      write(*,*)' x out of range HBm1101.  x = ',x
      endif
      
      return
      end      
      
      
      function HBm1100(x) !B7 
      implicit none
      include 'types.f'
      include 'constants.f'
      include 'HPLsinclude.f'
      real(dp):: x,HBm1100,myli2,myli3,myli4,Zeta,li4half,y
      external Zeta
      external myli3
      external myli2,myli4
      real(dp):: HBm1m110
      real(dp):: HB0111,HB0001,HBm1111,HBm1110,HBm1101,
     & HBm1011,HBm1010,HBm1001,HBm1000,HBm10m11
      real(dp):: HBm1m1m10,HBm1m1m11,HBm1m100,HBm1m101,HBm1m111
c        
      external HBm1m110
      external HB0111,HB0001,HBm1111,HBm1110,
     & HBm1011,HBm1010,HBm1001,HBm1000,HBm10m11
      external HBm1m1m10,HBm1m1m11,HBm1m100,HBm1m101,HBm1m111
c
      REAL*8   HB1,HB2,HB3,HB4
      INTEGER  IW 
      COMMON/WEIGHT/ IW
*  
      EXTERNAL HB1,HB2,HB3,HB4
c
      HBm1100 = zip
      li4half = 0.5174790616738993_dp
      if(0._dp<x.and.x<(sqrt(2._dp)-1._dp))then
      HBm1100 = HB4(-1,1,0,0,x)
      elseif((sqrt(2._dp)-1._dp)<x.and.x<1._dp)then
      y = (1._dp - x)/(1._dp + x)
      HBm1100 = (19._dp*Pi**4)/1440._dp + HBm1011(y) - 2._dp*HBm1m101(y) - 
     -  HBm1m111(y) + 3._dp*HBm1m1m10(y) + 2._dp*HBm1m1m11(y) - 
     -  Hm1(y)**4/24._dp + (Hm1(y)**2*Hm10(y))/2._dp + 
     -  Hm1(y)*Hm12(y) - 2._dp*Hm1(y)*Hm1m10(y) - 
     -  Hm1(y)*Hm1m11(y) - Hm1(y)*Zeta(3) - 
     -  (3._dp*Log(2._dp)*Zeta(3))/4._dp
      
      else
      write(*,*)' x out of range HBm1110.  x = ',x
      endif
      
      return
      end          


      function HBm1011(x) !B8
      implicit none
      include 'types.f'
      include 'constants.f'
      include 'HPLsinclude.f'
      real(dp):: x,HBm1011,myli2,myli3,myli4,Zeta,li4half,y
      external Zeta
      external myli3
      external myli2,myli4
      real(dp):: HBm1m110
      real(dp):: HB0111,HB0001,HBm1110,HBm1101,HBm1100,
     & HBm1010,HBm1001,HBm1000,HBm10m11
      real(dp):: HBm1m1m10,HBm1m1m11,HBm1m100,HBm1m101,HBm1m111
c        
      external HBm1m110
      external HB0111,HB0001,HBm1110,HBm1101,HBm1100,
     & HBm1010,HBm1001,HBm1000,HBm10m11
      external HBm1m1m10,HBm1m1m11,HBm1m100,HBm1m101,HBm1m111
c
      REAL*8   HB1,HB2,HB3,HB4
      INTEGER  IW 
      COMMON/WEIGHT/ IW
*  
      EXTERNAL HB1,HB2,HB3,HB4
c
      HBm1011 = zip
      li4half = 0.5174790616738993_dp
      if(0._dp<x.and.x<(sqrt(2._dp)-1._dp))then
      HBm1011 = HB4(-1,0,1,1,x)
      elseif((sqrt(2._dp)-1._dp)<x.and.x<1._dp)then
      y = (1._dp - x)/(1._dp + x)
      HBm1011 = -li4half + Pi**4/288._dp + HBm1100(y) + HBm1m100(y) + 
     -  2._dp*HBm1m110(y) + 2._dp*HBm1m1m10(y) + 3._dp*HBm1m1m11(y) + 
     -  Hm1(y)**4/24._dp + (Hm1(y)**2*Hm11(y))/2._dp - Hm1(y)*Hm110(y) - 
     -  Hm1(y)*Hm1m10(y) - 2._dp*Hm1(y)*Hm1m11(y) - 
     -  (Hm1(y)**3*Log(2._dp))/6._dp - Hm1(y)*Hm11(y)*Log(2._dp) + 
     -  Hm110(y)*Log(2._dp) + Hm1m10(y)*Log(2._dp) + 2*Hm1m11(y)*Log(2._dp) + 
     -  (Pi**2*Log(2._dp)**2)/24._dp + (Hm1(y)**2*Log(2._dp)**2)/4._dp + 
     -  (Hm11(y)*Log(2._dp)**2)/2._dp - Log(2._dp)**4/24._dp - Hm1(y)*Zeta(3) + 
     -  (Log(2._dp)*Zeta(3))/8._dp
      
      else
      write(*,*)' x out of range HBm1011.  x = ',x
      endif
      
      return
      end   



      function HBm1010(x) !B9
      implicit none
      include 'types.f'
      include 'constants.f'
      include 'HPLsinclude.f'
      real(dp):: x,HBm1010,myli2,myli3,myli4,Zeta,li4half,y
      external Zeta
      external myli3
      external myli2,myli4
      real(dp):: HBm1m110
      real(dp):: HB0111,HB0001,HBm1111,HBm1110,HBm1101,
     & HBm1011,HBm1001,HBm1000,HBm10m11
      real(dp):: HBm1m1m10,HBm1m1m11,HBm1m100,HBm1m101,HBm1m111
c        
      external HBm1m110
      external HB0111,HB0001,HBm1111,HBm1110,
     & HBm1011,HBm1001,HBm1000,HBm10m11
      external HBm1m1m10,HBm1m1m11,HBm1m100,HBm1m101,HBm1m111
c
      REAL*8   HB1,HB2,HB3,HB4
      INTEGER  IW 
      COMMON/WEIGHT/ IW
*  
      EXTERNAL HB1,HB2,HB3,HB4
c
c      write(*,*)' dentro HBm1010 '
      HBm1010 = zip
      li4half = 0.5174790616738993_dp
      if(0._dp<x.and.x<(sqrt(2._dp)-1._dp))then
      HBm1010 = HB4(-1,0,1,0,x)
      elseif((sqrt(2._dp)-1._dp)<x.and.x<1._dp)then
      y = (1._dp - x)/(1._dp + x)
      HBm1010 = 4._dp*li4half - (17._dp*Pi**4)/480._dp + HBm10m11(y) + HBm1101(y) + 
     -  3._dp*HBm1m101(y) + 2._dp*HBm1m111(y) - 3._dp*HBm1m1m10(y) - 
     -  4._dp*HBm1m1m11(y) - (Pi**2*Hm1(y)**2)/12._dp - Hm1(y)**4/24._dp - 
     -  (Pi**2*Hm11(y))/6._dp - (Hm1(y)**2*Hm11(y))/2._dp - 
     -  Hm10(y)*Hm11(y) - Hm11(y)**2/2._dp + Hm1(y)*Hm110(y) + 
     -  Hm1(y)*Hm1m10(y) + 2._dp*Hm1(y)*Hm1m11(y) - 
     -  (Pi**2*Log(2._dp)**2)/6._dp + Log(2._dp)**4/6._dp + 2._dp*Hm1(y)*Zeta(3) + 
     -  (3._dp*Log(2._dp)*Zeta(3))/2._dp
      
      else
      write(*,*)' x out of range HBm1110.  x = ',x
      endif
      
      return
      end             


      function HBm1001(x) !B10
      implicit none
      include 'types.f'
      include 'constants.f'
      include 'HPLsinclude.f'
      real(dp):: x,HBm1001,myli2,myli3,myli4,Zeta,li4half,y
      external Zeta
      external myli3
      external myli2,myli4
      real(dp):: HBm1m110
      real(dp):: HB0111,HB0001,HBm1111,HBm1110,HBm1101,
     & HBm1011,HBm1000,HBm10m11
      real(dp):: HBm1m1m10,HBm1m1m11,HBm1m100,HBm1m101,HBm1m111
c        
      external HBm1m110
      external HB0111,HB0001,HBm1111,HBm1110,
     & HBm1011,HBm1000,HBm10m11
      external HBm1m1m10,HBm1m1m11,HBm1m100,HBm1m101,HBm1m111
c
      REAL*8   HB1,HB2,HB3,HB4
      INTEGER  IW 
      COMMON/WEIGHT/ IW
*  
      EXTERNAL HB1,HB2,HB3,HB4
c
      HBm1001 = zip
      li4half = 0.5174790616738993_dp
      if(0._dp<x.and.x<(sqrt(2._dp)-1._dp))then
      HBm1001 = HB4(-1,0,0,1,x)
      elseif((sqrt(2._dp)-1._dp)<x.and.x<1._dp)then
      y = (1._dp - x)/(1._dp + x)
      HBm1001 = -2._dp*li4half + Pi**4/60._dp - HBm10m11(y) + HBm1110(y) - 
     -  2*HBm1m101(y) - HBm1m110(y) + HBm1m1m10(y) + 
     -  (Pi**2*Hm1(y)**2)/12._dp - Hm1(y)**4/24._dp + 
     -  (Pi**2*Hm11(y))/6._dp - (Hm1(y)**2*Hm11(y))/2._dp + 
     -  Hm10(y)*Hm11(y) + Hm11(y)**2/2._dp - Hm1(y)*Hm111(y) + 
     -  Hm1(y)*Hm1m11(y) + (Hm1(y)**3*Log(2._dp))/6._dp + 
     -  Hm1(y)*Hm11(y)*Log(2._dp) + Hm111(y)*Log(2._dp) - 
     -  Hm1m11(y)*Log(2._dp) + (Pi**2*Log(2._dp)**2)/12._dp - Log(2._dp)**4/12. - 
     -  Hm1(y)*Zeta(3) - (3._dp*Log(2._dp)*Zeta(3))/4._dp
      
      else
      write(*,*)' x out of range HBm1110.  x = ',x
      endif
      
      return
      end       


      function HBm1000(x) !B11 Checked
      implicit none
      include 'types.f'
      include 'constants.f'
      include 'HPLsinclude.f'
      real(dp):: x,HBm1000,myli2,myli3,myli4,Zeta
      external Zeta
      external myli3
      external myli2,myli4
c
      HBm1000 =      (Log(x)**3*Log(1 + x))/6. + (Log(x)**2*myli2(-x))/2. - 
     -  Log(x)*myli3(-x) + myli4(-x)
      
      return
      end  
      
      
      
      
      function HBm10m11(x) !B12 Checked
      implicit none
      include 'types.f'
      include 'constants.f'
      include 'HPLsinclude.f'
      real(dp):: HBm10m11,x,myli2,myli3,myli4,Zeta,y,li4half
      external Zeta
      external myli3
      real(dp):: HBm1m110
      real(dp):: HB0111,HB0001,HBm1111,HBm1110,HBm1101,
     & HBm1011,HBm1000
      real(dp):: HBm1m1m10,HBm1m1m11,HBm1m100,HBm1m101,HBm1m111
c        
      external HBm1m110
      external HB0111,HB0001,HBm1111,HBm1110,
     & HBm1011,HBm1000
      external HBm1m1m10,HBm1m1m11,HBm1m100,HBm1m101,HBm1m111
      
c
      REAL*8   HB1,HB2,HB3,HB4
      INTEGER  IW 
      COMMON/WEIGHT/ IW
*  
      EXTERNAL HB1,HB2,HB3,HB4
c
      HBm10m11 = zip
      li4half = 0.5174790616738993_dp
      if(0._dp<x.and.x<(sqrt(2._dp)-1._dp))then
      HBm10m11 = HB4(-1,0,-1,1,x)
      elseif((sqrt(2._dp)-1._dp)<x.and.x<1._dp)then
      y = (1._dp - x)/(1._dp + x)
       HBm10m11 = -4._dp*li4half + (5._dp*Pi**4)/144._dp - HB4(-1,0,-1,1,y) - 
     -  2._dp*HBm1m101(y) - 2*HBm1m110(y) + HBm1m1m10(y) - 
     -  3._dp*HBm1m1m11(y) + (Pi**2*Hm1(y)**2)/24._dp - Hm1(y)**4/24._dp + 
     -  (Pi**2*Hm11(y))/12._dp - (Hm1(y)**2*Hm11(y))/2._dp + 
     -  Hm10(y)*Hm11(y) + 2._dp*Hm1(y)*Hm1m11(y) + 
     -  (Pi**2*Hm1(y)*Log(2._dp))/4._dp + (Hm1(y)**3*Log(2._dp))/6._dp + 
     -  Hm1(y)*Hm11(y)*Log(2._dp) - 2*Hm1m11(y)*Log(2._dp) - 
     -  (Pi**2*Log(2._dp)**2)/12._dp - (Hm1(y)**2*Log(2._dp)**2)/4._dp - 
     -  (Hm11(y)*Log(2._dp)**2)/2._dp - Log(2._dp)**4/6._dp - 
     -  (13._dp*Hm1(y)*Zeta(3))/8._dp - Log(2._dp)*Zeta(3)
      else
      write(*,*)' x out of range HBm10m11.  x = ',x
      endif
      
      return
      end    
      
      
      function HBm1m111(x) 
      implicit none
      include 'types.f'
      include 'constants.f'
      include 'HPLsinclude.f'
      real(dp):: x,HBm1m111,myli2,myli3,myli4,Zeta,li4half,y
      external Zeta
      external myli3
      external myli2,myli4
      real(dp):: HBm1m110
      real(dp):: HB0111,HB0001,HBm1110,HBm1101,HBm1100,
     & HBm1010,HBm1001,HBm1000,HBm10m11
      real(dp):: HBm1m1m10,HBm1m1m11,HBm1m100,HBm1m101
c        
      external HBm1m110
      external HB0111,HB0001,HBm1110,HBm1101,HBm1100,
     & HBm1010,HBm1001,HBm1000,HBm10m11
      external HBm1m1m10,HBm1m1m11,HBm1m100
c
      REAL*8   HB1,HB2,HB3,HB4
      INTEGER  IW 
      COMMON/WEIGHT/ IW
*  
      EXTERNAL HB1,HB2,HB3,HB4
c
      HBm1m111 = zip
      li4half = 0.5174790616738993_dp
      if(0._dp<x.and.x<(sqrt(2._dp)-1._dp))then
      HBm1m111 = HB4(-1,-1,1,1,x)
      elseif((sqrt(2._dp)-1._dp)<x.and.x<1._dp)then
      y = (1._dp - x)/(1._dp + x)
      HBm1m111 = Pi**4/720._dp + HBm1m100(y) + 2._dp*HBm1m1m10(y) + 
     -  Hm1(y)**4/24._dp - Hm1(y)*Hm1m10(y) + 
     -  (Pi**2*Hm1(y)*Log(2._dp))/12._dp - (Hm1(y)**3*Log(2._dp))/6._dp + 
     -  Hm1m10(y)*Log(2._dp) + (Hm1(y)**2*Log(2._dp)**2)/4._dp - 
     -  (Hm1(y)*Log(2._dp)**3)/6._dp + Log(2._dp)**4/24._dp - 
     -  (7._dp*Hm1(y)*Zeta(3))/8._dp - (Log(2._dp)*Zeta(3))/8._dp
      
      else
      write(*,*)' x out of range HBm1m111.  x = ',x
      endif
      
      return
      end   
 

      function HBm1m110(x) !B14 Checked
      implicit none
      include 'types.f'
      include 'constants.f'
      include 'HPLsinclude.f'
      real(dp):: x,HBm1m110,myli2,myli3,myli4,Zeta,li4half,y
      external Zeta
      external myli3
      external myli2,myli4
      real(dp):: HB0111,HB0001,HBm1111,HBm1110,HBm1101,HBm1100,
     & HBm1011,HBm1010,HBm1001,HBm1000,HBm10m11
      real(dp):: HBm1m1m10,HBm1m1m11,HBm1m100,HBm1m101,HBm1m111
c        
      external HB0111,HB0001,HBm1111,HBm1110,HBm1101,HBm1100,
     & HBm1011,HBm1010,HBm1001,HBm1000,HBm10m11
      external HBm1m1m10,HBm1m1m11,HBm1m100,HBm1m101,HBm1m111
c
      REAL*8   HB1,HB2,HB3,HB4
      INTEGER  IW 
      COMMON/WEIGHT/ IW
*  
      EXTERNAL HB1,HB2,HB3,HB4
c
      HBm1m110 = zip
      li4half = 0.5174790616738993_dp
      if(0._dp<x.and.x<(sqrt(2._dp)-1._dp))then
      HBm1m110 = HB4(-1,-1,1,0,x)
      elseif((sqrt(2._dp)-1._dp)<x.and.x<1._dp)then
      y = (1._dp - x)/(1._dp + x)
      HBm1m110 = 2._dp*li4half - (7._dp*Pi**4)/288._dp + HBm1m101(y) - 
     -  3._dp*HBm1m1m10(y) - HBm1m1m11(y) - (Pi**2*Hm1(y)**2)/12._dp - 
     -  Hm1(y)**4/24._dp + Hm1(y)*Hm1m10(y) - 
     -  (Pi**2*Hm1(y)*Log(2._dp))/12._dp - (Pi**2*Log(2._dp)**2)/24._dp + 
     -  Log(2._dp)**4/12._dp + Hm1(y)*Zeta(3) + (13._dp*Log(2._dp)*Zeta(3))/8._dp
      
      else
      write(*,*)' x out of range HBm1m110.  x = ',x
      endif
      
      return
      end 
      
      
      function HBm1m101(x) !B15
      implicit none
      include 'types.f'
      include 'constants.f'
      include 'HPLsinclude.f'
      real(dp):: x,HBm1m101,myli2,myli3,myli4,Zeta,li4half,y
      external Zeta
      external myli3
      external myli2,myli4
      real(dp):: HB0111,HB0001,HBm1111,HBm1110,HBm1101,HBm1100,
     & HBm1011,HBm1010,HBm1001,HBm1000,HBm10m11
      real(dp):: HBm1m1m10,HBm1m1m11,HBm1m100,HBm1m111,HBm1m110
c        
      external HB0111,HB0001,HBm1111,HBm1110,HBm1101,HBm1100,
     & HBm1011,HBm1010,HBm1001,HBm1000,HBm10m11
      external HBm1m1m10,HBm1m1m11,HBm1m100,HBm1m111,HBm1m110
c
      REAL*8   HB1,HB2,HB3,HB4
      INTEGER  IW 
      COMMON/WEIGHT/ IW
*  
      EXTERNAL HB1,HB2,HB3,HB4
c
      HBm1m101 = zip
      li4half = 0.5174790616738993_dp
      if(0._dp<x.and.x<(sqrt(2._dp)-1._dp))then
      HBm1m101 = HB4(-1,-1,0,1,x)
      elseif((sqrt(2._dp)-1._dp)<x.and.x<1._dp)then
      y = (1._dp - x)/(1._dp + x)
      HBm1m101 = Pi**4/480._dp + HBm1m110(y) + HBm1m1m10(y) + 3*HBm1m1m11(y) + 
     -  (Pi**2*Hm1(y)**2)/12._dp - Hm1(y)**4/24._dp - Hm1(y)*Hm1m11(y) - 
     -  (Pi**2*Hm1(y)*Log(2._dp))/6._dp + (Hm1(y)**3*Log(2._dp))/6._dp + 
     -  Hm1m11(y)*Log(2._dp) + (Pi**2*Log(2._dp)**2)/12._dp + 
     -  (5._dp*Hm1(y)*Zeta(3))/8._dp - (5._dp*Log(2._dp)*Zeta(3))/8._dp
      
      else
      write(*,*)' x out of range HBm1m101.  x = ',x
      endif
      
      return
      end         


      function HBm1m100(x) !B16
      implicit none
      include 'types.f'
      include 'constants.f'
      include 'HPLsinclude.f'
      real(dp):: x,HBm1m100,myli2,myli3,myli4,Zeta
      external Zeta
      external myli3
      external myli2,myli4
c
      HBm1m100 = Pi**4/90. - (Pi**2*Log(x)*Log(1 + x))/6. + (Pi**2*Log(1 + x)**2)/12. - 
     -  (Log(x)**2*Log(1 + x)**2)/4. + (Log(x)*Log(1 + x)**3)/3. - Log(1 + x)**4/12. - 
     -  Log(x)*myli3(1/(1 + x)) - myli4(-x) - myli4(1/(1 + x)) - 
     -  myli4(x/(1 + x)) + Log(x)*Zeta(3) - Log(1 + x)*Zeta(3)
      
      return
      end        
      
      
      function HBm1m1m11(x) 
      implicit none
      include 'types.f'
      include 'constants.f'
      include 'HPLsinclude.f'
      real(dp):: x,HBm1m1m11,myli2,myli3,myli4,Zeta
      external Zeta
      external myli3
      external myli2,myli4
c
      HBm1m1m11 = -H4(0.5_dp) + (Pi**2*Log(2._dp)*Log(1 + x))/12. - (Log(2._dp)**3*Log(1 + x))/6. - 
     -  (Pi**2*Log(1 + x)**2)/24. + (Log(2._dp)**2*Log(1 + x)**2)/4. - 
     -  (Log(2._dp)*Log(1 + x)**3)/6. + myli4((1 + x)/2.) - (7*Log(1 + x)*Zeta(3))/8.
      
      return
      end        


      function HBm1m1m10(x) !B18
      implicit none
      include 'types.f'
      include 'constants.f'
      include 'HPLsinclude.f'
      real(dp):: x,HBm1m1m10,myli2,myli3,myli4,Zeta
      external Zeta
      external myli3
      external myli2,myli4
c
      HBm1m1m10 = -Pi**4/90. - (Pi**2*Log(1 + x)**2)/12. + Log(1 + x)**4/24. + 
     -  myli4(1/(1 + x)) + Log(1 + x)*Zeta(3)
      
      return
      end    
